@@ -29,6 +29,7 @@
 #include <KCalendarCore/Event>
 #endif
 
+#include <kcontacts_version.h>
 #include <KContacts/Address>
 
 #include <KLocalizedString>
@@ -39,19 +40,33 @@
 
 using namespace KItinerary;
 
-static QString formatAddress(const PostalAddress &addr)
+static KContacts::Address convertAddress(const PostalAddress &addr)
 {
     KContacts::Address a;
     a.setStreet(addr.streetAddress());
     a.setPostalCode(addr.postalCode());
     a.setLocality(addr.addressLocality());
-    a.setCountry(KContacts::Address::ISOtoCountry(addr.addressCountry()));
-    return a.formattedAddress();
+    a.setRegion(addr.addressRegion());
+    a.setCountry(addr.addressCountry());
+    return a;
+}
+
+static QString formatAddress(const PostalAddress &addr)
+{
+#if KContacts_VERSION >= QT_VERSION_CHECK(5, 92, 0)
+    return convertAddress(addr).formatted(KContacts::AddressFormatStyle::MultiLineInternational);
+#else
+    return convertAddress(addr).formattedAddress();
+#endif
 }
 
 static QString formatAddressSingleLine(const PostalAddress &addr)
 {
+#if KContacts_VERSION >= QT_VERSION_CHECK(5, 92, 0)
+    return convertAddress(addr).formatted(KContacts::AddressFormatStyle::SingleLineInternational);
+#else
     return formatAddress(addr).replace(QLatin1String("\n\n"), QLatin1String("\n")).replace(QLatin1Char('\n'), QLatin1String(", "));
+#endif
 }
 
 #ifdef HAVE_KCAL
@@ -439,7 +454,6 @@ static void fillGeoPosition(const QVariant &place, const KCalendarCore::Event::P
         return;
     }
 
-    event->setHasGeo(true);
     event->setGeoLatitude(geo.latitude());
     event->setGeoLongitude(geo.longitude());
 }
