@@ -38,8 +38,7 @@ QDate Rct2TicketPrivate::firstDayOfValidity() const
     if (it == f.end()) {
         return {};
     }
-
-    const auto dtStr = f.midRef(std::distance(f.begin(), it));
+    const auto dtStr = QStringView(f).mid(std::distance(f.begin(), it));
     auto dt = QDate::fromString(dtStr.left(10).toString(), QStringLiteral("dd.MM.yyyy"));
     if (dt.isValid()) {
         return dt;
